@@ -435,14 +435,32 @@ static char *
 prompt_for_password(void)
 {
 	char *buf;
+	static char *passwdbuf;
+	static bool have_passwd = false;
+
 #define BUFSIZE 100
 
 #if PG_VERSION_NUM < 100000
-	buf = simple_prompt("Password: ", BUFSIZE, false);
+	if (have_passwd) {
+		buf = pgut_malloc(BUFSIZE);
+		memcpy(buf, passwdbuf, sizeof(char)*BUFSIZE);
+	} else {
+		buf = simple_prompt("Password: ", BUFSIZE, false);
+		have_passwd = true;
+		passwdbuf = pgut_malloc(BUFSIZE);
+		memcpy(passwdbuf, buf, sizeof(char)*BUFSIZE);
+	}
 #else
-	buf = (char *)malloc(BUFSIZE);
-	if (buf != NULL)
-		simple_prompt("Password: ", buf, BUFSIZE, false);
+	buf = pgut_malloc(BUFSIZE);
+	if (have_passwd) {
+		memcpy(buf, passwdbuf, sizeof(char)*BUFSIZE);
+	} else {
+		if (buf != NULL)
+			simple_prompt("Password: ", buf, BUFSIZE, false);
+		have_passwd = true;
+		passwdbuf = pgut_malloc(BUFSIZE);
+		memcpy(passwdbuf, buf, sizeof(char)*BUFSIZE);
+	}
 #endif
 
 	if (buf == NULL)
